==> thirdparty-service-api-1.0.33.p4-20211018.061918-1-sources.jar: cn/com/duiba/thirdparty/dto/zhiji/request/ZhiJiOrderHead.java <==
package cn.com.duiba.thirdparty.dto.zhiji.request;

import java.io.Serializable;

/**
 * @author: pengyi
 * @description:
 * @date: 2021/9/7 下午8:45
 */
public class ZhiJiOrderHead implements Serializable {

    private static final long serialVersionUID = 6094027810196524045L;
    /**
     * 收货人电话
     */
    private String imContactPhone;
    /**
     * 积分+钱，单位积分
     */
    private String imAmount;
    /**
     * 下单时间
     */
    private String orderDate;
    /**
     * 订单渠道
     */
    private String imOrderChannel;
    /**
     * 智己superId
     */
    private String imSuperId;
    /**
     * 兑吧订单号
     */
    private String weborderNumber;
    /**
     * 下单地址快照
     */
    private String imLicenseAddress;
    /**
     * 商品兑换积分
     */
    private String imPoints;

    /**
     * 订单备注：用户输入的订单备注
     */
    private String comments;

    /**
     * 省份
     */
    private String imLicenseState;

    /**
     * 城市
     */
    private String imLicenseCity;

    /**
     * 区县
     */
    private String imLicenseCounty;

    /**
     * 街道
     */
    private String imLicenseStreet;

    /**
     * 收货人
     */
    private String imContactFullName;

    /**
     * 收货人联系电话
     */
    private String imLicensePhone;
    /**
     * 订单状态: 待发货waitSend、待付款waitPay、已发货shipped、确认收货ConfirmReceipt、申请售后ApplyAfterSale、成功success、失败false
     */
    private String status;

    private ListOfOrderLine ListOforderLine;

    private ListOfPayment ListOfpayment;

    public String getImContactPhone() {
        return imContactPhone;
    }

    public void setImContactPhone(String imContactPhone) {
        this.imContactPhone = imContactPhone;
    }

    public String getImAmount() {
        return imAmount;
    }

    public void setImAmount(String imAmount) {
        this.imAmount = imAmount;
    }

    public String getOrderDate() {
        return orderDate;
    }

    public void setOrderDate(String orderDate) {
        this.orderDate = orderDate;
    }

    public String getImOrderChannel() {
        return imOrderChannel;
    }

    public void setImOrderChannel(String imOrderChannel) {
        this.imOrderChannel = imOrderChannel;
    }

    public String getImSuperId() {
        return imSuperId;
    }

    public void setImSuperId(String imSuperId) {
        this.imSuperId = imSuperId;
    }

    public String getWeborderNumber() {
        return weborderNumber;
    }

    public void setWeborderNumber(String weborderNumber) {
        this.weborderNumber = weborderNumber;
    }

    public String getImLicenseAddress() {
        return imLicenseAddress;
    }

    public void setImLicenseAddress(String imLicenseAddress) {
        this.imLicenseAddress = imLicenseAddress;
    }

    public String getImPoints() {
        return imPoints;
    }

    public void setImPoints(String imPoints) {
        this.imPoints = imPoints;
    }

    public String getComments() {
        return comments;
    }

    public void setComments(String comments) {
        this.comments = comments;
    }

    public String getImLicenseState() {
        return imLicenseState;
    }

    public void setImLicenseState(String imLicenseState) {
        this.imLicenseState = imLicenseState;
    }

    public String getImLicenseCity() {
        return imLicenseCity;
    }

    public void setImLicenseCity(String imLicenseCity) {
        this.imLicenseCity = imLicenseCity;
    }

    public String getImLicenseCounty() {
        return imLicenseCounty;
    }

    public void setImLicenseCounty(String imLicenseCounty) {
        this.imLicenseCounty = imLicenseCounty;
    }

    public String getImLicenseStreet() {
        return imLicenseStreet;
    }

    public void setImLicenseStreet(String imLicenseStreet) {
        this.imLicenseStreet = imLicenseStreet;
    }

    public String getImContactFullName() {
        return imContactFullName;
    }

    public void setImContactFullName(String imContactFullName) {
        this.imContactFullName = imContactFullName;
    }

    public String getImLicensePhone() {
        return imLicensePhone;
    }

    public void setImLicensePhone(String imLicensePhone) {
        this.imLicensePhone = imLicensePhone;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public ListOfOrderLine getListOforderLine() {
        return ListOforderLine;
    }

    public void setListOforderLine(ListOfOrderLine listOforderLine) {
        ListOforderLine = listOforderLine;
    }

    public ListOfPayment getListOfpayment() {
        return ListOfpayment;
    }

    public void setListOfpayment(ListOfPayment listOfpayment) {
        ListOfpayment = listOfpayment;
    }
}

==> thirdparty-service-api-1.0.94-sources.jar: cn/com/duiba/thirdparty/dto/zhiji/request/ZhiJiOrderHead.java <==
package cn.com.duiba.thirdparty.dto.zhiji.request;

import com.alibaba.fastjson.annotation.JSONField;

import java.io.Serializable;

/**
 * @author: pengyi
 * @description:
 * @date: 2021/9/7 下午8:45
 */
public class ZhiJiOrderHead implements Serializable {

    private static final long serialVersionUID = 6094027810196524045L;
    /**
     * 收货人电话
     */
    private String imContactPhone;
    /**
     * 积分+钱，单位积分
     */
    private String imAmount;
    /**
     * 下单时间
     */
    private String orderDate;
    /**
     * 订单渠道
     */
    private String imOrderChannel;
    /**
     * 智己superId
     */
    private String imSuperId;
    /**
     * 兑吧订单号
     */
    private String weborderNumber;
    /**
     * 下单地址快照
     */
    private String imLicenseAddress;
    /**
     * 商品兑换积分
     */
    private String imPoints;

    /**
     * 订单备注：用户输入的订单备注
     */
    private String comments;

    /**
     * 省份
     */
    private String imLicenseState;

    /**
     * 城市
     */
    private String imLicenseCity;

    /**
     * 区县
     */
    private String imLicenseCounty;

    /**
     * 街道
     */
    private String imLicenseStreet;

    /**
     * 收货人
     */
    private String imContactFullName;

    /**
     * 收货人联系电话
     */
    private String imLicensePhone;
    /**
     * 订单状态: 待发货waitSend、待付款waitPay、已发货shipped、确认收货ConfirmReceipt、申请售后ApplyAfterSale、成功success、失败false
     */
    private String status;

    @JSONField(name = "ListOforderLine")
    private ListOfOrderLine ListOforderLine;

    @JSONField(name = "ListOfpayment")
    private ListOfPayment ListOfpayment;

    public String getImContactPhone() {
        return imContactPhone;
    }

    public void setImContactPhone(String imContactPhone) {
        this.imContactPhone = imContactPhone;
    }

    public String getImAmount() {
        return imAmount;
    }

    public void setImAmount(String imAmount) {
        this.imAmount = imAmount;
    }

    public String getOrderDate() {
        return orderDate;
    }

    public void setOrderDate(String orderDate) {
        this.orderDate = orderDate;
    }

    public String getImOrderChannel() {
        return imOrderChannel;
    }

    public void setImOrderChannel(String imOrderChannel) {
        this.imOrderChannel = imOrderChannel;
    }

    public String getImSuperId() {
        return imSuperId;
    }

    public void setImSuperId(String imSuperId) {
        this.imSuperId = imSuperId;
    }

    public String getWeborderNumber() {
        return weborderNumber;
    }

    public void setWeborderNumber(String weborderNumber) {
        this.weborderNumber = weborderNumber;
    }

    public String getImLicenseAddress() {
        return imLicenseAddress;
    }

    public void setImLicenseAddress(String imLicenseAddress) {
        this.imLicenseAddress = imLicenseAddress;
    }

    public String getImPoints() {
        return imPoints;
    }

    public void setImPoints(String imPoints) {
        this.imPoints = imPoints;
    }

    public String getComments() {
        return comments;
    }

    public void setComments(String comments) {
        this.comments = comments;
    }

    public String getImLicenseState() {
        return imLicenseState;
    }

    public void setImLicenseState(String imLicenseState) {
        this.imLicenseState = imLicenseState;
    }

    public String getImLicenseCity() {
        return imLicenseCity;
    }

    public void setImLicenseCity(String imLicenseCity) {
        this.imLicenseCity = imLicenseCity;
    }

    public String getImLicenseCounty() {
        return imLicenseCounty;
    }

    public void setImLicenseCounty(String imLicenseCounty) {
        this.imLicenseCounty = imLicenseCounty;
    }

    public String getImLicenseStreet() {
        return imLicenseStreet;
    }

    public void setImLicenseStreet(String imLicenseStreet) {
        this.imLicenseStreet = imLicenseStreet;
    }

    public String getImContactFullName() {
        return imContactFullName;
    }

    public void setImContactFullName(String imContactFullName) {
        this.imContactFullName = imContactFullName;
    }

    public String getImLicensePhone() {
        return imLicensePhone;
    }

    public void setImLicensePhone(String imLicensePhone) {
        this.imLicensePhone = imLicensePhone;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public ListOfOrderLine getListOforderLine() {
        return ListOforderLine;
    }

    public void setListOforderLine(ListOfOrderLine listOforderLine) {
        ListOforderLine = listOforderLine;
    }

    public ListOfPayment getListOfpayment() {
        return ListOfpayment;
    }

    public void setListOfpayment(ListOfPayment listOfpayment) {
        ListOfpayment = listOfpayment;
    }
}
